# Example Dataset Implementations

> [!WARNING]
> Install UltraAugment and prepare the datasets using the CLI before running any examples.

- [PyTorch datasets with Albumentations support](/examples/pytorch_datasets_with_albumentations.py)